@@ -1,5 +1,10 @@
+#include <Rcpp.h>
+#include <vector>
+
 #include "primes.h"
 
+// [[Rcpp::interfaces(r, cpp)]]
+
 //' @rdname generate_primes
 //' @export
 // [[Rcpp::export]]
